==> haskell-text-iso8601-0.1.1-53.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-text-iso8601.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-iso8601
version:              0.1.1
visibility:           public
id:                   text-iso8601-0.1.1-GF0rdlvxt50LplRlzOpaT9
key:                  text-iso8601-0.1.1-GF0rdlvxt50LplRlzOpaT9
license:              BSD-3-Clause
copyright:            Oleg Grenrus <oleg.grenrus@iki.fi>
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/haskell/aeson
synopsis:             Converting time to and from ISO 8601 text.
description:
    Converting time to and from IS0 8601 text.
    Specifically the [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339) profile.

category:             Parsing
abi:                  954bef17e326e0de266884068a580432
exposed:              True
exposed-modules:      Data.Time.FromText Data.Time.ToText
import-dirs:          /usr/lib/ghc-9.6.6/site-local/text-iso8601-0.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/text-iso8601-0.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/text-iso8601-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-iso8601
hs-libraries:         HStext-iso8601-0.1.1-GF0rdlvxt50LplRlzOpaT9
depends:
    base-4.18.2.1 integer-conversion-0.1.1-DRB3SWHoRBCJxKDeuc2gjJ
    text-2.0.2 time-1.12.2 time-compat-1.9.8-KXBZmSgVcbpGOqrx2hUfcV

haddock-interfaces:
    /usr/share/doc/haskell-text-iso8601/html/text-iso8601.haddock

haddock-html:         /usr/share/doc/haskell-text-iso8601/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-iso8601-0.1.1-54-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-text-iso8601.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-iso8601
version:              0.1.1
visibility:           public
id:                   text-iso8601-0.1.1-7s9wfG1NH3F6HcPkFbTT6y
key:                  text-iso8601-0.1.1-7s9wfG1NH3F6HcPkFbTT6y
license:              BSD-3-Clause
copyright:            Oleg Grenrus <oleg.grenrus@iki.fi>
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/haskell/aeson
synopsis:             Converting time to and from ISO 8601 text.
description:
    Converting time to and from IS0 8601 text.
    Specifically the [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339) profile.

category:             Parsing
abi:                  6731229805e6530cd07650ecfd39b61a
exposed:              True
exposed-modules:      Data.Time.FromText Data.Time.ToText
import-dirs:          /usr/lib/ghc-9.6.6/site-local/text-iso8601-0.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/text-iso8601-0.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/text-iso8601-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-iso8601
hs-libraries:         HStext-iso8601-0.1.1-7s9wfG1NH3F6HcPkFbTT6y
depends:
    base-4.18.2.1 integer-conversion-0.1.1-1JOh3kEXs2A1lWf7CGpMKt
    text-2.0.2 time-1.12.2 time-compat-1.9.8-ITy6Cf33IaSAWRM66COV33

haddock-interfaces:
    /usr/share/doc/haskell-text-iso8601/html/text-iso8601.haddock

haddock-html:         /usr/share/doc/haskell-text-iso8601/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
